"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_stage_configs_1 = require("./get_stage_configs");
const buildActionOutputArtifacts = {
    'secondary-artifacts': {
        build: {
            files: '**/*',
            name: 'build',
        },
        dist: {
            files: ['dist/**/*'],
            name: 'dist',
        },
    },
};
const deployActionOutputArtifacts = {
    'secondary-artifacts': {
        cfurl: {
            files: ['/tmp/cfurl.txt'],
            name: 'cfurl',
        },
        deploy: {
            files: '**/*',
            name: 'deploy',
        },
    },
};
function addPipelineStages(stack, params) {
    const sourceAction = stack.addSourceStage('source', get_stage_configs_1.getSourceConfig(params, 0));
    stack.addBuildActionStage('test', get_stage_configs_1.getTestConfig(params, 1, sourceAction.outputArtifact));
    const buildAction = stack.addBuildActionStage('build', Object.assign({}, get_stage_configs_1.getBuildConfig(params, 2, sourceAction.outputArtifact), { outputArtifacts: buildActionOutputArtifacts }));
    const deployAction = stack.addBuildActionStage('deploy', Object.assign({}, get_stage_configs_1.getDeployConfig(params, 3, sourceAction.outputArtifact), { additionalInputArtifacts: [buildAction.additionalOutputArtifact('dist')], outputArtifacts: deployActionOutputArtifacts }));
    stack.addBuildActionStage('end2end-test', Object.assign({}, get_stage_configs_1.getTestEnd2EndConfig(params, 4, sourceAction.outputArtifact), { additionalInputArtifacts: [deployAction.additionalOutputArtifact('cfurl')] }));
}
exports.addPipelineStages = addPipelineStages;
//# sourceMappingURL=build_pipeline.js.map